PCB Environment: IVector_3 Class Reference

PCB Environment 2

Loading...
Searching...
No Matches
Public Member Functions | Data Fields
IVector_3 Class Reference

## Public Member Functions
| IVector_3 (int X, int Y, int Z)
| IVector_3 (const IVector_2 &v, int Z)
| IVector_3 (const IVector_3 &v)
IVector_3 & | operator= (const IVector_3 &v)
bool | operator== (const IVector_3 &v) const
bool | operator!= (const IVector_3 &v) const
IVector_3 | operator+ (const IVector_3 &v) const
IVector_3 | operator- (const IVector_3 &v) const
IVector_3 | operator* (int s) const
IVector_3 | operator/ (int s) const
IVector_3 & | operator+= (const IVector_3 &v)
IVector_3 & | operator-= (const IVector_3 &v)
IVector_3 & | operator*= (int s)
IVector_3 & | operator/= (int s)
IVector_3 | abs () const
int32_t | dot (const IVector_3 &v) const
int32_t | norm1 () const
int32_t | hprod () const
IVector_3 | max_cw (const IVector_3 &v) const
IVector_3 | min_cw (const IVector_3 &v) const

## Data Fields
int32_t | x
int32_t | y
int32_t | z

The documentation for this class was generated from the following file:

- /home/chr/devel/PhD/Environment/pub/PCBEnv/pcbenv/cxx/Math/IPoint3.hpp